@@ -32,11 +32,30 @@ def unpack_ushort(data: bytearray) -> int:
     """Unpacks unsigned short number from bytes.
 
     Keyword arguments:
-    data - bytes to unpack number from
+    data -- bytes to unpack number from
     """
     return int.from_bytes(data, byteorder="little", signed=False)
 
 
+def unpack_parameter(data: bytearray, offset: int, size: int = 1) -> (int, int, int):
+    """Unpacks parameter.
+
+    Keyword arguments:
+    data -- bytes to unpack number from
+    offset -- data offset
+    size -- parameter size in bytes
+    """
+
+    if not check_parameter(data[offset : offset + size * 3]):
+        return None
+
+    value = unpack_ushort(data[offset : offset + size])
+    min_ = unpack_ushort(data[offset + size : offset + 2 * size])
+    max_ = unpack_ushort(data[offset + 2 * size : offset + 3 * size])
+
+    return value, min_, max_
+
+
 def ip_to_bytes(address: str) -> bytearray:
     """Converts ip address to bytes.
 
@@ -99,8 +118,9 @@ def uid_stamp(message: str) -> str:
         for _ in range(8):
             if crc_ & 1:
                 crc_ = (crc_ >> 1) ^ 0xA001
-            else:
-                crc_ = crc_ >> 1
+                continue
+
+            crc_ = crc_ >> 1
 
     return chr(crc_ % 256) + chr((crc_ // 256) % 256)
 
@@ -120,3 +140,18 @@ def uid_5bits_to_char(number: int) -> str:
     char = chr(ord("A") + number - 10)
 
     return "Z" if char == "O" else char
+
+
+def make_list(data: dict, include_keys: bool = True):
+    """Converts dictionary to string.
+
+    Keyword arguments:
+    data -- dictionary to convert to string
+    include_keys -- determines if keys should be included
+    """
+
+    output = ""
+    for k, v in data.items():
+        output += f"- {k}: {v}\n" if include_keys else f"- {v}\n"
+
+    return output.rstrip()
